========================
Team and repository tags
========================

.. image:: https://governance.openstack.org/tc/badges/python-blazarclient.svg
    :target: https://governance.openstack.org/tc/reference/tags/index.html

.. Change things from this point on

=============
Blazar client
=============

This is a client for the OpenStack Blazar API. It provides a Python API (the
**blazarclient** module) and a command-line script (**blazar**).

Other Resources
---------------

* Source code:

    * `Blazar <https://opendev.org/openstack/blazar>`__
    * `Nova scheduler filter <https://opendev.org/openstack/blazar-nova>`__
    * `Client tools <https://opendev.org/openstack/python-blazarclient>`__
    * `Dashboard (Horizon plugin) <https://opendev.org/openstack/blazar-dashboard>`__

* Blueprints/Bugs: https://launchpad.net/blazar
* Documentation: https://docs.openstack.org/blazar/latest/
* Release notes: https://docs.openstack.org/releasenotes/python-blazarclient/
